@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Inspect musical modal functions
 
-our $VERSION = '0.0407';
+our $VERSION = '0.0408';
 
 use strictures 2;
 use AI::Prolog ();
@@ -271,24 +271,42 @@ Music::ModalFunction - Inspect musical modal functions
 
 =head1 VERSION
 
-version 0.0407
+version 0.0408
 
 =head1 SYNOPSIS
 
   use Music::ModalFunction ();
 
-  # What can have a Dmaj dominant chord?
+  # What chords do C major and A minor have in common?
   my $m = Music::ModalFunction->new(
+    mode_note    => 'c',
+    mode         => 'ionian',
+    key_note     => 'a',
+    key          => 'aeolian',
+  );
+  my $results = $m->pivot_chord_keys; # 7 common chords
+
+  # What chords do C major and F♯ (G♭) major have in common?
+  $m = Music::ModalFunction->new(
+    mode_note    => 'c',
+    mode         => 'ionian',
+    key_note     => 'gb',
+    key          => 'ionian',
+  );
+  $results = $m->pivot_chord_keys; # No chords in common!
+
+  # What modes can have a Dmaj dominant chord?
+  $m = Music::ModalFunction->new(
     chord_note   => 'd',
     chord        => 'maj',
     key_function => 'dominant',
   );
-  my $results = $m->chord_key;
+  $results = $m->chord_key;
   # [[ 'chord_key', 'd', 'maj', 'g', 'ionian', 'dominant', 'r_V' ],
   #  [ 'chord_key', 'd', 'maj', 'g', 'lydian', 'dominant', 'r_V' ]]
   # So the answers are G Ionian and G Lydian.
 
-  # Where can a Gmaj chord function as a subdominant pivot chord?
+  # In what modes can a Gmaj chord function as a subdominant pivot chord?
   $m = Music::ModalFunction->new(
     chord_note   => 'g',
     chord        => 'maj',
@@ -302,24 +320,6 @@ version 0.0407
   #  ... ]
   # Inspecting all the results, we see that the answers are D Dorian, D Ionian, and D Mixolydian.
 
-  # What chords do C major and A minor have in common?
-  $m = Music::ModalFunction->new(
-    mode_note    => 'c',
-    mode         => 'ionian',
-    key_note     => 'a',
-    key          => 'aeolian',
-  );
-  $results = $m->pivot_chord_keys; # 7 common chords
-
-  # What chords do C major and F♯ (G♭) major have in common?
-  $m = Music::ModalFunction->new(
-    mode_note    => 'c',
-    mode         => 'ionian',
-    key_note     => 'gb',
-    key          => 'ionian',
-  );
-  $results = $m->pivot_chord_keys; # There are no chords in common!
-
 =head1 DESCRIPTION
 
 C<Music::ModalFunction> allows querying of a musical database of
@@ -484,7 +484,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2023 by Gene Boggs.
+This software is Copyright (c) 2023-2024 by Gene Boggs.
 
 This is free software, licensed under:
 
